Function debug
pub fn debug(error: BevyError, ctx: ErrorContext)Expand description
Error handler that logs the system error at the debug level.
pub fn debug(error: BevyError, ctx: ErrorContext)Error handler that logs the system error at the debug level.