Function error
pub fn error(error: BevyError, ctx: ErrorContext)Expand description
Error handler that logs the system error at the error level.
pub fn error(error: BevyError, ctx: ErrorContext)Error handler that logs the system error at the error level.