Function trace
pub fn trace(error: BevyError, ctx: ErrorContext)Expand description
Error handler that logs the system error at the trace level.
pub fn trace(error: BevyError, ctx: ErrorContext)Error handler that logs the system error at the trace level.