Function warn
pub fn warn(error: BevyError, ctx: ErrorContext)Expand description
Error handler that logs the system error at the warn level.
pub fn warn(error: BevyError, ctx: ErrorContext)Error handler that logs the system error at the warn level.